@@ -40,7 +40,6 @@ from setfit import SetFitModel
 
 from kneed import KneeLocator
 import matplotlib.pyplot as plt
-from sklearn.metrics import precision_recall_curve, roc_curve
 
 import nlpaug.augmenter.char as nac
 
@@ -232,6 +231,7 @@ class RouteBuilder:
                   text_column: str = "text", 
                   train_samples: int = 12, 
                   label_mapping = None,
+                  apply_route_template=True
                   ) -> Optional[Dataset]:
         """
         Loads data from a file or Hugging Face dataset.
@@ -248,7 +248,7 @@ class RouteBuilder:
                 encoding = self._detect_encoding(file_path)
                 df = pd.read_csv(path, delimiter=",", encoding=encoding)
                 df[label_column] = df[label_column].apply(lambda x: x.title() if x != self.oos_label else x)
-                if self.route_template is not None:
+                if apply_route_template is True and self.route_template is not None:
                     df[label_column] = df[label_column].apply(lambda x: self.route_template.format(x) if x != self.oos_label else x )
             elif path.suffix == '.jsonl':
                 with open(path, 'r', encoding="utf-8") as f:
@@ -866,7 +866,7 @@ class RouteBuilder:
             self.logger.info("Calibrated head saved successfully")
             self.logger.debug(calibrated_model.classes_)
 
-            if self.eval_path is not None:
+            if self.eval_path is None:
                 self._display_calibration_trend(val_text_embeddings, val_labels, classifier_head, calibrated_model, output_dir)
             
         except Exception as e:
@@ -1117,7 +1117,7 @@ class RouteBuilder:
         """
         downloaded_models = self._get_downloaded_models()
         if not any(model_name in downloaded_model for downloaded_model in downloaded_models):
-            self.logger.info(f"Downloading model '{model_name}'...")
+            self.logger.info(f"Downloading model '{model_name}'...This can take a min..")
             ollama.pull(model_name)
             self.logger.info(f"Model '{model_name}' has been successfully downloaded.")  
 
@@ -1288,7 +1288,7 @@ class RouteBuilder:
                 train_path = f"{self.synthetic_data_dir}/train_{self.domain}_{timestamp}.csv"
                 self.build_request.to_csv(train_path)
                 number_of_synthetic_samples = self.samples_per_route if self.samples_per_route else self.fallback_samples_per_route 
-                train_dataset = self._load_data(file_path=train_path)
+                train_dataset = self._load_data(file_path=train_path, apply_route_template= False)
                 self.logger.info(f"Augmenting synthetic data from your sample <query,label> pairs:")
                 if self.eval_path:
                     number_of_synthetic_samples = self.samples_per_route if self.samples_per_route else self.min_samples
@@ -1328,8 +1328,8 @@ class RouteBuilder:
             train_file, eval_file = self.train_path, self.eval_path
 
 
-        train_without_adv_dataset = self._load_data(train_file)
-        eval_without_adv_dataset =  self._load_data(eval_file)
+        train_without_adv_dataset = self._load_data(train_file, apply_route_template= False)
+        eval_without_adv_dataset =  self._load_data(eval_file, apply_route_template= False)
         train_without_adv_dataset = train_without_adv_dataset.filter(lambda x: x['label'] != self.route_template.format(self.oos_label))
         eval_without_adv_dataset = eval_without_adv_dataset.filter(lambda x: x['label'] != self.route_template.format(self.oos_label))
 
@@ -1339,20 +1339,20 @@ class RouteBuilder:
         if self.enable_id_oos_gen:
             self.logger.info(f"Generating adversarial i.e. ID OOS based on training samples")
             train_adv_file, eval_adv_file = self._generate_adversarial_samples(train_samples=train_without_adv_dataset, number_of_synthetic_samples=number_of_synthetic_samples + 10, domain=self.domain, route_template=self.route_template, model=self.llm_name, prefix=prefix, user_instructions=self.instruct_llm)
-            train_dataset = concatenate_datasets([train_without_adv_dataset, self._load_data(train_adv_file)])
-            eval_dataset = concatenate_datasets([eval_without_adv_dataset, self._load_data(eval_adv_file)])
+            train_dataset = concatenate_datasets([train_without_adv_dataset, self._load_data(train_adv_file, apply_route_template= False)])
+            eval_dataset = concatenate_datasets([eval_without_adv_dataset, self._load_data(eval_adv_file, apply_route_template= False)])
             train_dataset.to_csv(train_file, index=False)
             eval_dataset.to_csv(eval_file, index=False)
         else:    
             self.logger.info(f"Warning: enable_id_oos_gen is turned off, assuming your training samples have `{self.oos_label}` labeled queries")
-            train_dataset = self._load_data(train_file)
-            eval_dataset =  self._load_data(eval_file)
+            train_dataset = self._load_data(train_file, apply_route_template= False)
+            eval_dataset =  self._load_data(eval_file, apply_route_template= False)
 
         self.logger.info(f"Training dataset w/ ID OOS {train_dataset.num_rows}")
         self.logger.info(f"Eval dataset w/ ID OOS {eval_dataset.num_rows}")
 
         if self.enable_test_dataset_gen:
-            train_dataset = self._load_data(train_file)
+            train_dataset = self._load_data(train_file, apply_route_template= False)
             test_file = self._generate_synthetic_test_queries(self.routes, 
                                                                 self.domain, 
                                                                 samples_per_route=self.test_samples_per_route, 
@@ -1364,7 +1364,7 @@ class RouteBuilder:
         
         if self.add_additional_invalid_routes:    
             train_additional_invalid_file = self._generate_additional_invalid_routes(prefix)
-            train_additional_invalid_dataset = self._load_data(train_additional_invalid_file)
+            train_additional_invalid_dataset = self._load_data(train_additional_invalid_file, apply_route_template= False)
             train_dataset = concatenate_datasets([train_dataset, train_additional_invalid_dataset])
             train_dataset.to_csv(train_file, index=False)
             self.logger.info(f"Training dataset w Additional Invalid OOS {train_dataset.num_rows}")
@@ -1402,26 +1402,3 @@ class RouteBuilder:
             self.logger.info("Thank you for using route0x! May all your queries find their way.")
 
 
-
-# routebuilder = RouteBuilder(
-#             seed = 1234,
-#             train_path = "./generated_datasets/synthetic_llama3.1_personal_assistant_20241109_164543_train.csv",
-#             eval_path = "./generated_datasets/synthetic_llama3.1_personal_assistant_20241109_164543_eval.csv",
-#             loss_funct_name="PairwiseArcFaceFocalLoss",
-#             oos_label = "NO_NODES_DETECTED",
-#             expected_oos_proportion =  0.1,
-#             nn_for_oos_detection = 10,
-#             max_query_len = 64,
-#             domain="personal assistant",
-#             max_steps=100,
-#             warmup_proportion=0.05,
-#             # llm_name="llama3.1",
-#             enable_test_dataset_gen = False,
-#             enable_synth_data_gen = False,
-#             enable_id_oos_gen = False,
-#             skip_eval = False,
-#             add_additional_invalid_routes = False,
-#             log_level = "info",
-#     )
-
-# routebuilder.build_routes()
\ No newline at end of file
